.. _spkg_kerrgeodesic_gw:

kerrgeodesic_gw: Gravitational radiation from material orbiting a Kerr black hole
===========================================================================================

Description
-----------

Gravitational radiation from material orbiting a Kerr black hole

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/kerrgeodesic-gw/


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_sagemath_plot`
- :ref:`spkg_sagemath_symbolics`

Version Information
-------------------

requirements.txt::

    kerrgeodesic-gw


Equivalent System Packages
--------------------------

(none known)

